=======
History
=======


0.1.0 (2018-12-24)
------------------

* Initial release with complete implementatin of first-order Krotov's method
* Support for state-to-state and gate optimization, for both closed and open systems


0.0.1 (2018-11-06)
------------------

* Non-functional placeholder release
